# Changelog
All notable changes to this project will be documented in this file.

## [Unreleased]

## [0.2.2] - 2022-07-29

### Fixed
- Fixed PyPI upload yet again.

## [0.2.1] - 2022-07-29

### Fixed
- Fixed GitHub action for PyPI upload.

## [0.2.0] - 2022-07-29

### Added
- Allow users to specify `b0` parameter in scale-dependent bias term.

## [0.1.0] - 2020-01-25

Initial release
